@@ -63,7 +63,7 @@ setMethod("itemFrequencyPlot", signature(x = "itemMatrix"),
     function(x, type = c("relative", "absolute"), support = NULL, 
         topN = NULL, population = NULL, popCol = "black", popLwd = 1, 
         lift = FALSE, horiz = FALSE,
-        names = TRUE, cex.names =  par("cex.axis"), 
+        names = TRUE, cex.names =  graphics::par("cex.axis"), 
         xlab = NULL, ylab = NULL, mai = NULL, ...) {
 
         type <- match.arg(type)
@@ -147,7 +147,8 @@ setMethod("itemFrequencyPlot", signature(x = "itemMatrix"),
 
 ## helper functions for barplot
 .barplot_vert <- function(height, ..., 
-    cex.names = par("cex.axis"), xlab = NULL, ylab = NULL, mai = NULL){
+    cex.names = graphics::par("cex.axis"), 
+	xlab = NULL, ylab = NULL, mai = NULL){
 
     labels <- names(height)
 
@@ -155,54 +156,54 @@ setMethod("itemFrequencyPlot", signature(x = "itemMatrix"),
     if(min(height, na.rm = TRUE) < 0) straight <- TRUE
     else straight <- FALSE
 
-    op.mai <- par("mai")
+    op.mai <- graphics::par("mai")
     if(is.null(mai)) {
         mai <- op.mai
-        if (straight == TRUE) mai[1] <- max(strwidth(labels, units = "inches",
-                cex = cex.names)) + min(par("fin")[2]*0.1, 0.5)
-        else mai[1] <- max(strwidth(labels, units = "inches",
-                cex = cex.names)) / 2^.5 + min(par("fin")[2]*0.1, 0.5)
+        if (straight == TRUE) mai[1] <- max(graphics::strwidth(labels, units = "inches",
+                cex = cex.names)) + min(graphics::par("fin")[2]*0.1, 0.5)
+        else mai[1] <- max(graphics::strwidth(labels, units = "inches",
+                cex = cex.names)) / 2^.5 + min(graphics::par("fin")[2]*0.1, 0.5)
     } 
 
-    par(mai = mai) 
-    on.exit(par(mai = op.mai))
+    graphics::par(mai = mai) 
+    on.exit(graphics::par(mai = op.mai))
 
     ## Create plot with no x axis and no x axis label
 
     if(straight == TRUE)
-    bp <- barplot(height, ...,  las=2, cex.names = cex.names, 
+    bp <- graphics::barplot(height, ...,  las=2, cex.names = cex.names, 
         xlab = xlab, ylab = ylab)
 
     else {
-        bp <- barplot(height, ..., xaxt = "n",  xlab = "", ylab = ylab)
+        bp <- graphics::barplot(height, ..., xaxt = "n",  xlab = "", ylab = ylab)
 
         ## move down from the lower end of the plot by 1/20 of the plotting
         ## area for labels
-        text(bp, par("usr")[3] - (par("usr")[4] - par("usr")[3]) / 20, 
+        graphics::text(bp, graphics::par("usr")[3] - (graphics::par("usr")[4] - graphics::par("usr")[3]) / 20, 
             srt = 45, adj = 1,
             labels = labels, xpd = TRUE, cex = cex.names)
 
         ## Plot x axis label
-        mtext(1, text = xlab, line = par("mar")[1]-1)
+        graphics::mtext(1, text = xlab, line = graphics::par("mar")[1]-1)
     }
     invisible(bp)
 }
 
 .barplot_horiz <- function(height, ..., 
-    cex.names = par("cex.axis"), xlab = NULL, ylab = NULL, mai = NULL){
+    cex.names = graphics::par("cex.axis"), xlab = NULL, ylab = NULL, mai = NULL){
 
     ## make enough space for item labels
-    op.mai <- par("mai")
+    op.mai <- graphics::par("mai")
     if(is.null(mai)) {
         mai <- op.mai
-        mai[2] <- max(strwidth(names(height), units = "inches", 
-                cex = cex.names)) + min(par("fin")[1]*0.1, 0.5)
+        mai[2] <- max(graphics::strwidth(names(height), units = "inches", 
+                cex = cex.names)) + min(graphics::par("fin")[1]*0.1, 0.5)
 
     }
-    par(mai = mai) 
-    on.exit(par(mai = op.mai))
+    graphics::par(mai = mai) 
+    on.exit(graphics::par(mai = op.mai))
 
-    midpoints <- barplot(height, 
+    midpoints <- graphics::barplot(height, 
         las = 2, cex.name = cex.names, horiz = TRUE,
         xlab = xlab, ylab = ylab, ...)
 
